Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | class |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
src / main / python / okta_api_script / __init__.py | (no class) |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / okta_api_script / cli.py | (no class) |  | 92% | 12 | 1 | 0 |  | 100% | 0 | 0 |  | 92%
src / main / python / okta_api_script / main.py | (no class) |  | 95% | 37 | 2 | 0 |  | 83% | 12 | 2 |  | 92%
src / main / python / services / __init__.py | (no class) |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / enrollment.py | (no class) |  | 100% | 9 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / projects.py | (no class) |  | 100% | 13 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / resource_groups.py | (no class) |  | 100% | 24 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / service_token.py | (no class) |  | 100% | 16 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
Total |  |  | 97% | 117 | 3 | 0 |  | 83% | 12 | 2 |  | 96%

No items found using the specified filter.